@@ -42,6 +42,7 @@ module Yesod.Form.Fields
     , fileAFormOpt
       -- * Options
       -- $optionsOverview
+    , selectFieldHelper
     , selectField
     , selectFieldList
     , radioField
@@ -106,6 +107,8 @@ import Data.Attoparsec.Text (Parser, char, string, digit, skipSpace, endOfInput,
 
 import Yesod.Persist.Core
 
+import Data.String (IsString)
+
 #if !MIN_VERSION_base(4,8,0)
 import Data.Monoid
 #endif
@@ -217,7 +220,7 @@ $newline never
 -- If this text is then placed verbatim into HTML, the lines won't be separated, thus the need for replacing with @\<br>@ tags).
 -- If you don't need this functionality, simply use 'unTextarea' to access the raw text.
 newtype Textarea = Textarea { unTextarea :: Text }
-    deriving (Show, Read, Eq, PersistField, Ord, ToJSON, FromJSON)
+    deriving (Show, Read, Eq, PersistField, Ord, ToJSON, FromJSON, IsString)
 instance PersistFieldSql Textarea where
     sqlType _ = SqlString
 instance ToHtml Textarea where
@@ -727,11 +730,15 @@ optionsPersistKey filts ords toDisplay = fmap mkOptionList $ do
         , optionExternalValue = toPathPiece key
         }) pairs
 
+-- |
+-- A helper function for constucting 'selectField's. You may want to use this when you define your custom 'selectField's or 'radioField's.
+--
+-- @since 1.6.2
 selectFieldHelper
         :: (Eq a, RenderMessage site FormMessage)
-        => (Text -> Text -> [(Text, Text)] -> WidgetFor site () -> WidgetFor site ())
-        -> (Text -> Text -> Bool -> WidgetFor site ())
-        -> (Text -> Text -> [(Text, Text)] -> Text -> Bool -> Text -> WidgetFor site ())
+        => (Text -> Text -> [(Text, Text)] -> WidgetFor site () -> WidgetFor site ()) -- ^ Outermost part of the field
+        -> (Text -> Text -> Bool -> WidgetFor site ()) -- ^ An option for None if the field is optional
+        -> (Text -> Text -> [(Text, Text)] -> Text -> Bool -> Text -> WidgetFor site ()) -- ^ Other options
         -> HandlerFor site (OptionList a)
         -> Field (HandlerFor site) a
 selectFieldHelper outside onOpt inside opts' = Field
